@@ -21,9 +21,7 @@
 
 namespace RDKit {
 namespace Chirality {
-#ifndef _MSC_VER
-const unsigned StereoInfo::NOATOM = std::numeric_limits<unsigned>::max();
-#endif
+
 namespace detail {
 
 bool isAtomPotentialNontetrahedralCenter(const Atom *atom) {
@@ -157,7 +155,7 @@ StereoInfo getStereoInfo(const Bond *bond) {
       }
 
       for (unsigned i = atom->getDegree(); i < 3; ++i) {
-        sinfo.controllingAtoms.push_back(StereoInfo::NOATOM);
+        sinfo.controllingAtoms.push_back(Atom::NOATOM);
       }
     };
 
@@ -247,7 +245,7 @@ StereoInfo getStereoInfo(const Bond *bond) {
       }
     }
     if (beginAtom->getDegree() == 2) {
-      sinfo.controllingAtoms.push_back(StereoInfo::NOATOM);
+      sinfo.controllingAtoms.push_back(Atom::NOATOM);
     }
     for (const auto nbr : mol.atomBonds(endAtom)) {
       if (nbr->getIdx() != bond->getIdx()) {
@@ -256,7 +254,7 @@ StereoInfo getStereoInfo(const Bond *bond) {
       }
     }
     if (endAtom->getDegree() == 2) {
-      sinfo.controllingAtoms.push_back(StereoInfo::NOATOM);
+      sinfo.controllingAtoms.push_back(Atom::NOATOM);
     }
 
     Bond::BondStereo stereo = bond->getStereo();
@@ -453,9 +451,9 @@ bool areStereobondControllingAtomsDupes(
     const boost::dynamic_bitset<> &knownAtoms,
     const boost::dynamic_bitset<> &possibleBonds,
     const boost::dynamic_bitset<> &knownBonds) {
-  PRECONDITION(controllingAtom1 != Chirality::StereoInfo::NOATOM &&
-                   controllingAtom2 != Chirality::StereoInfo::NOATOM,
-               "Missing a controlling atom");
+  PRECONDITION(
+      controllingAtom1 != Atom::NOATOM && controllingAtom2 != Atom::NOATOM,
+      "Missing a controlling atom");
 
   if (atomRanks[controllingAtom1] != atomRanks[controllingAtom2]) {
     return false;
@@ -890,10 +888,10 @@ bool updateBonds(ROMol &mol, const std::vector<unsigned int> &aranks,
       ASSERT_INVARIANT(sinfo.controllingAtoms.size() == 4,
                        "bad controlling atoms size");
 
-      if ((sinfo.controllingAtoms[0] == Chirality::StereoInfo::NOATOM &&
-           sinfo.controllingAtoms[1] == Chirality::StereoInfo::NOATOM) ||
-          (sinfo.controllingAtoms[2] == Chirality::StereoInfo::NOATOM &&
-           sinfo.controllingAtoms[3] == Chirality::StereoInfo::NOATOM)) {
+      if ((sinfo.controllingAtoms[0] == Atom::NOATOM &&
+           sinfo.controllingAtoms[1] == Atom::NOATOM) ||
+          (sinfo.controllingAtoms[2] == Atom::NOATOM &&
+           sinfo.controllingAtoms[3] == Atom::NOATOM)) {
         // we have a bond with no neighbors on one side, which means it must
         // have a single implicit H on that side. Since the H is implicit,
         // there is no way to know whether it is cis or trans.
@@ -908,8 +906,8 @@ bool updateBonds(ROMol &mol, const std::vector<unsigned int> &aranks,
       } else {
         bool haveADupe = false;
         bool needsSwap = false;
-        if (sinfo.controllingAtoms[0] != Chirality::StereoInfo::NOATOM &&
-            sinfo.controllingAtoms[1] != Chirality::StereoInfo::NOATOM) {
+        if (sinfo.controllingAtoms[0] != Atom::NOATOM &&
+            sinfo.controllingAtoms[1] != Atom::NOATOM) {
           if (areStereobondControllingAtomsDupes(
                   mol, *bond, sinfo.controllingAtoms[0],
                   sinfo.controllingAtoms[1], aranks, possibleAtoms, knownAtoms,
@@ -921,8 +919,8 @@ bool updateBonds(ROMol &mol, const std::vector<unsigned int> &aranks,
             needsSwap = !needsSwap;
           }
         }
-        if (sinfo.controllingAtoms[2] != Chirality::StereoInfo::NOATOM &&
-            sinfo.controllingAtoms[3] != Chirality::StereoInfo::NOATOM) {
+        if (sinfo.controllingAtoms[2] != Atom::NOATOM &&
+            sinfo.controllingAtoms[3] != Atom::NOATOM) {
           if (areStereobondControllingAtomsDupes(
                   mol, *bond, sinfo.controllingAtoms[2],
                   sinfo.controllingAtoms[3], aranks, possibleAtoms, knownAtoms,
