@@ -1764,7 +1764,7 @@ std::string get_sgroup_polymer_block(
     if (sg.getPropIfPresent("TYPE", typ) &&
         reverseTypemap.find(typ) != reverseTypemap.end()) {
       sg.setProp("_cxsmilesOutputIndex", sgroupOutputIndex);
-      sgroupOutputIndex++;
+      ++sgroupOutputIndex;
 
       res << "Sg:";
       std::string subtype;
@@ -1819,8 +1819,8 @@ std::string get_sgroup_polymer_block(
         res.seekp(-1, res.cur);
       }
       res << ":";
+      res << ",";  // only add a comma if we wrote something
     }
-    res << ",";
   }
 
   std::string resStr = res.str();
@@ -1852,7 +1852,7 @@ std::string get_sgroup_data_block(const ROMol &mol,
   for (const auto &sg : sgs) {
     if (sg.hasProp("TYPE") && sg.getProp<std::string>("TYPE") == "DAT") {
       sg.setProp("_cxsmilesOutputIndex", sgroupOutputIndex);
-      sgroupOutputIndex++;
+      ++sgroupOutputIndex;
 
       res << "SgD:";
       // we don't attempt to canonicalize the atom order because the user
@@ -1890,8 +1890,8 @@ std::string get_sgroup_data_block(const ROMol &mol,
       }
       res << ":";
       // FIX: do something about the coordinates
+      res << ",";  // only add a comma if we wrote something
     }
-    res << ",";
   }
 
   std::string resStr = res.str();
@@ -2109,7 +2109,7 @@ std::string get_bond_config_block(
             if (!Atropisomers::getAtropisomerAtomsAndBonds(
                     bondNbr, atomAndBondVecs, mol)) {
               throw ValueErrorException("Internal error - should not occur");
-              // should not happend
+              // should not happen
             } else {
               unsigned int swaps = 0;
 
@@ -2127,9 +2127,10 @@ std::string get_bond_config_block(
 
               for (unsigned int bondAtomIndex = 0; bondAtomIndex < 2;
                    ++bondAtomIndex) {
-                if (atomAndBondVecs[bondAtomIndex].first == firstAtom)
+                if (atomAndBondVecs[bondAtomIndex].first == firstAtom) {
                   continue;  // swapped atoms on the side where the wedge bond
                              // is does NOT change the wedge bond
+                }
                 if (atomAndBondVecs[bondAtomIndex].second.size() == 2) {
                   unsigned int firstOtherAtomIdx =
                       atomAndBondVecs[bondAtomIndex]
