@@ -150,10 +150,16 @@ void compareRingAtomsConcerningNumNeighbors(Canon::canon_atom *atoms,
   PRECONDITION(atoms, "bad pointer");
   RingInfo *ringInfo = mol.getRingInfo();
 
-  auto visited = std::make_unique<char[]>(nAtoms);
-  auto lastLevelNbrs = std::make_unique<char[]>(nAtoms);
-  auto currentLevelNbrs = std::make_unique<char[]>(nAtoms);
-  auto revisitedNeighbors = std::make_unique<int[]>(nAtoms);
+  std::vector<char> visited(nAtoms);
+  std::vector<char> lastLevelNbrs(nAtoms);
+  std::vector<char> currentLevelNbrs(nAtoms);
+  std::vector<int> revisitedNeighbors(nAtoms);
+
+  // Sparse index tracking vectors to avoid O(n) scans
+  std::vector<int> visitedIndices;
+  std::vector<int> lastLevelIndices;
+  std::vector<int> modifiedRevisited;
+
   for (unsigned idx = 0; idx < nAtoms; ++idx) {
     const Canon::canon_atom &a = atoms[idx];
     if (!ringInfo->isInitialized() ||
@@ -166,10 +172,17 @@ void compareRingAtomsConcerningNumNeighbors(Canon::canon_atom *atoms,
     atoms[idx].neighborNum.reserve(1000);
     atoms[idx].revistedNeighbors.assign(1000, 0);
 
-    memset(visited.get(), 0, nAtoms * sizeof(char));
-    memset(lastLevelNbrs.get(), 0, nAtoms * sizeof(char));
-    memset(currentLevelNbrs.get(), 0, nAtoms * sizeof(char));
-    memset(revisitedNeighbors.get(), 0, nAtoms * sizeof(int));
+    // Sparse reset from previous atom's BFS
+    for (int i : visitedIndices) {
+      visited[i] = 0;
+    }
+    visitedIndices.clear();
+    for (int i : lastLevelIndices) {
+      lastLevelNbrs[i] = 0;
+    }
+    // currentLevelNbrs and revisitedNeighbors are reset within the BFS loop
+    lastLevelIndices.clear();
+
     std::vector<int> nextLevelNbrs;
     while (!neighbors.empty()) {
       unsigned int numLevelNbrs = 0;
@@ -183,41 +196,52 @@ void compareRingAtomsConcerningNumNeighbors(Canon::canon_atom *atoms,
           continue;
         }
         lastLevelNbrs[nidx] = 1;
+        lastLevelIndices.push_back(nidx);
         visited[nidx] = 1;
+        visitedIndices.push_back(nidx);
         for (unsigned int j = 0; j < atom.degree; j++) {
           int iidx = atom.nbrIds[j];
           if (!visited[iidx]) {
             currentLevelNbrs[iidx] = 1;
             numLevelNbrs++;
             visited[iidx] = 1;
+            visitedIndices.push_back(iidx);
             nextLevelNbrs.push_back(iidx);
           }
         }
       }
-      for (unsigned i = 0; i < nAtoms; ++i) {
-        if (currentLevelNbrs[i]) {
-          const Canon::canon_atom &natom = atoms[i];
-          for (unsigned int k = 0; k < natom.degree; k++) {
-            int jidx = natom.nbrIds[k];
-            if (currentLevelNbrs[jidx] || lastLevelNbrs[jidx]) {
-              revisitedNeighbors[jidx] += 1;
+      // Use sparse iteration over nextLevelNbrs instead of O(n) scan
+      for (int i : nextLevelNbrs) {
+        const Canon::canon_atom &natom = atoms[i];
+        for (unsigned int k = 0; k < natom.degree; k++) {
+          int jidx = natom.nbrIds[k];
+          if (currentLevelNbrs[jidx] || lastLevelNbrs[jidx]) {
+            if (revisitedNeighbors[jidx] == 0) {
+              modifiedRevisited.push_back(jidx);
             }
+            revisitedNeighbors[jidx] += 1;
           }
         }
       }
-      memset(lastLevelNbrs.get(), 0, nAtoms * sizeof(char));
-      for (unsigned i = 0; i < nAtoms; ++i) {
-        if (currentLevelNbrs[i]) {
-          lastLevelNbrs[i] = 1;
-        }
+      // Sparse reset of lastLevelNbrs
+      for (int i : lastLevelIndices) {
+        lastLevelNbrs[i] = 0;
+      }
+      lastLevelIndices.clear();
+      // Copy current to last using sparse indices
+      for (int i : nextLevelNbrs) {
+        lastLevelNbrs[i] = 1;
+        lastLevelIndices.push_back(i);
+      }
+      // Sparse reset of currentLevelNbrs
+      for (int i : nextLevelNbrs) {
+        currentLevelNbrs[i] = 0;
       }
-      memset(currentLevelNbrs.get(), 0, nAtoms * sizeof(char));
       std::vector<int> tmp;
       tmp.reserve(30);
-      for (unsigned i = 0; i < nAtoms; ++i) {
-        if (revisitedNeighbors[i] > 0) {
-          tmp.push_back(revisitedNeighbors[i]);
-        }
+      // Use sparse iteration over modifiedRevisited instead of O(n) scan
+      for (int i : modifiedRevisited) {
+        tmp.push_back(revisitedNeighbors[i]);
       }
       std::sort(tmp.begin(), tmp.end());
       tmp.push_back(-1);
@@ -229,7 +253,11 @@ void compareRingAtomsConcerningNumNeighbors(Canon::canon_atom *atoms,
         atoms[idx].revistedNeighbors[currentRNIdx] = i;
         currentRNIdx++;
       }
-      memset(revisitedNeighbors.get(), 0, nAtoms * sizeof(int));
+      // Sparse reset of revisitedNeighbors
+      for (int i : modifiedRevisited) {
+        revisitedNeighbors[i] = 0;
+      }
+      modifiedRevisited.clear();
 
       atoms[idx].neighborNum.push_back(numLevelNbrs);
       atoms[idx].neighborNum.push_back(-1);
